import { ChangeEvent, FormEvent, useState } from "react";
import { Box, Button, Grid, TextField } from "@mui/material";
import FileInput from "../UI/Form/FileInput/FileInput.tsx";

interface IState {
  title: string;
  price: string;
  description: string;
  image: string;
}

interface IProps {
  onSubmit: (data: FormData) => void;
}
const ProductForm = ({ onSubmit }: IProps) => {
  const [state, setState] = useState<IState>({
    title: "",
    price: "",
    description: "",
    image: "",
  });

  const submitFormHandler = (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();

    const formData: FormData = new FormData();

    Object.keys(state).forEach((key) => {
      formData.append(key, state[key as keyof IState]);
    });

    onSubmit(formData);
  };

  const inputChangeHandler = (e: ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setState((prevState) => {
      return { ...prevState, [name]: value };
    });
  };

  const fileChangeHandler = (e: ChangeEvent<HTMLInputElement>) => {
    const name = e.target.name;
    if (e.target.files) {
      const file = e.target.files[0];

      setState((prevState) => ({
        ...prevState,
        [name]: file,
      }));
    }
  };

  return (
    <Box
      component="form"
      autoComplete="off"
      onSubmit={submitFormHandler}
      paddingY={2}
    >
      <Grid container direction="column" spacing={2}>
        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="title"
            label="Title"
            value={state.title}
            onChange={inputChangeHandler}
            name="title"
          />
        </Grid>

        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="price"
            label="Price"
            value={state.price}
            onChange={inputChangeHandler}
            name="price"
          />
        </Grid>

        <Grid item xs>
          <TextField
            fullWidth
            variant="outlined"
            id="description"
            label="Description"
            value={state.description}
            onChange={inputChangeHandler}
            name="description"
          />
        </Grid>

        <Grid item xs>
          <FileInput onChange={fileChangeHandler} name="image" label="Image" />
        </Grid>

        <Grid item xs>
          <Button type="submit" color="primary" variant="contained">
            Create
          </Button>
        </Grid>
      </Grid>
    </Box>
  );
};

export default ProductForm;
