import { ChangeEvent, ChangeEventHandler, useRef, useState } from "react";
import { Button, Grid, TextField, styled } from "@mui/material";

interface IProps {
  onChange: ChangeEventHandler<HTMLInputElement>;
  name: string;
  label: string;
}

const HiddenInputFile = styled("input")({
  display: "none",
});

const FileInput = ({ onChange, name, label }: IProps) => {
  const inputRef = useRef<HTMLInputElement>(null);

  const [fileName, setFileName] = useState("");

  const onFileChange = (e: ChangeEvent<HTMLInputElement>) => {
    if (e.target.files && e.target.files[0]) {
      setFileName(e.target.files[0].name);
    } else {
      setFileName("");
    }
    onChange(e);
  };

  const activeInput = () => {
    if (inputRef.current) {
      inputRef.current.click();
    }
  };

  return (
    <>
      <HiddenInputFile
        type="file"
        name={name}
        onChange={onFileChange}
        ref={inputRef}
      />
      <Grid container direction="row" spacing={2} alignItems="center">
        <Grid item xs>
          <TextField
            variant="outlined"
            disabled
            fullWidth
            label={label}
            value={fileName}
            onClick={activeInput}
          />
        </Grid>
        <Grid item>
          <Button variant="contained" onClick={activeInput}>
            Browse
          </Button>
        </Grid>
      </Grid>
    </>
  );
};

export default FileInput;
